---
title: Library
---

<CardGroup cols={2}>
  <Card title="Rock, Paper, Scissors" icon="hand-scissors" href="/examples/rock-paper-scissors">
    Play a game of rock, paper, scissors against an AI - without letting it cheat.
  </Card>
  <Card title="Customer Call Routing" icon="phone" href="/examples/call-routing">
    Two agents cooperate to route customer calls to the correct department.
  </Card>
  <Card title="Software Engineer" icon="code" href="/examples/agent-engineer">
    An autonomous software engineer that creates applications based on your input.
  </Card>
  <Card title="Don't Panic." icon="paper-plane">
    More examples are on the way!
  </Card>
</CardGroup>
